==> fastproto-3.1.0-sources.jar: org/indunet/fastproto/decoder/CharacterDecoder.java <==
/*
 * Copyright 2019-2021 indunet
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.indunet.fastproto.decoder;

import lombok.NonNull;
import org.indunet.fastproto.EndianPolicy;
import org.indunet.fastproto.annotation.type.CharacterType;
import org.indunet.fastproto.exception.DecodingException;
import org.indunet.fastproto.util.CodecUtils;

/**
 * Character type decoder.
 *
 * @author Deng Ran
 * @see TypeDecoder,CharacterType
 * @since 1.1.0
 */
public class CharacterDecoder implements TypeDecoder<Character> {
    @Override
    public Character decode(DecodeContext context) {
        CharacterType type = context.getTypeAnnotation(CharacterType.class);
        EndianPolicy policy = context.getEndianPolicy();

        return this.decode(context.getDatagram(), type.value(), policy);
    }

    public Character decode(final byte[] datagram, int offset, @NonNull EndianPolicy policy) {
        try {
            return CodecUtils.characterType(datagram, offset, policy);
        } catch (ArrayIndexOutOfBoundsException e) {
            throw new DecodingException("Fail decoding the character type.", e);
        }
    }
}

==> fastproto-3.2.0-sources.jar: org/indunet/fastproto/decoder/CharacterDecoder.java <==
/*
 * Copyright 2019-2021 indunet
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.indunet.fastproto.decoder;

import lombok.NonNull;
import org.indunet.fastproto.EndianPolicy;
import org.indunet.fastproto.annotation.type.CharType;
import org.indunet.fastproto.exception.DecodingException;
import org.indunet.fastproto.util.CodecUtils;

/**
 * Character type decoder.
 *
 * @author Deng Ran
 * @see TypeDecoder, CharType
 * @since 1.1.0
 */
public class CharacterDecoder implements TypeDecoder<Character> {
    @Override
    public Character decode(DecodeContext context) {
        CharType type = context.getTypeAnnotation(CharType.class);
        EndianPolicy policy = context.getEndianPolicy();

        return this.decode(context.getDatagram(), type.value(), policy);
    }

    public Character decode(final byte[] datagram, int offset, @NonNull EndianPolicy policy) {
        try {
            return CodecUtils.characterType(datagram, offset, policy);
        } catch (ArrayIndexOutOfBoundsException e) {
            throw new DecodingException("Fail decoding the character type.", e);
        }
    }
}
